'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _uuid = require('uuid');

exports.default = function (context) {
  var stroke = null;
  var points = [];

  var onMouseDown = function onMouseDown(x, y, color, size) {
    stroke = {
      id: (0, _uuid.v4)(),
      tool: 'PENCIL',
      color: color,
      size: size,
      points: [{ x: x, y: y }]
    };
    return [stroke];
  };

  var onMouseMove = function onMouseMove(x, y) {
    if (!stroke) return [];

    var newPoint = { x: x, y: y };

    context.save();
    context.lineJoin = 'round';
    context.lineCap = 'round';
    context.beginPath();
    context.lineWidth = stroke.size;
    context.strokeStyle = stroke.color;
    context.globalCompositeOperation = 'source-over';

    var start = stroke.points.slice(-1)[0];
    context.moveTo(start.x, start.y);

    context.lineTo(x, y);
    context.closePath();
    context.stroke();
    context.restore();

    stroke.points.push(newPoint);
    points.push(newPoint);

    return [stroke];
  };

  var onDebouncedMouseMove = function onDebouncedMouseMove() {
    var debouncedPoints = points;
    points = [];
    return [stroke, debouncedPoints];
  };

  var onMouseUp = function onMouseUp(x, y) {
    if (!stroke) return;
    onMouseMove(x, y);
    points = [];
    var item = stroke;
    stroke = null;
    return [item];
  };

  return {
    onMouseDown: onMouseDown,
    onMouseMove: onMouseMove,
    onDebouncedMouseMove: onDebouncedMouseMove,
    onMouseUp: onMouseUp
  };
};